var SvelteFa = (function () {
  'use strict';

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    subClass.__proto__ = superClass;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };
    return _getPrototypeOf(o);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;
      return o;
    };

    return _setPrototypeOf(o, p);
  }

  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  function _construct(Parent, args, Class) {
    if (isNativeReflectConstruct()) {
      _construct = Reflect.construct;
    } else {
      _construct = function _construct(Parent, args, Class) {
        var a = [null];
        a.push.apply(a, args);
        var Constructor = Function.bind.apply(Parent, a);
        var instance = new Constructor();
        if (Class) _setPrototypeOf(instance, Class.prototype);
        return instance;
      };
    }

    return _construct.apply(null, arguments);
  }

  function _isNativeFunction(fn) {
    return Function.toString.call(fn).indexOf("[native code]") !== -1;
  }

  function _wrapNativeSuper(Class) {
    var _cache = typeof Map === "function" ? new Map() : undefined;

    _wrapNativeSuper = function _wrapNativeSuper(Class) {
      if (Class === null || !_isNativeFunction(Class)) return Class;

      if (typeof Class !== "function") {
        throw new TypeError("Super expression must either be null or a function");
      }

      if (typeof _cache !== "undefined") {
        if (_cache.has(Class)) return _cache.get(Class);

        _cache.set(Class, Wrapper);
      }

      function Wrapper() {
        return _construct(Class, arguments, _getPrototypeOf(this).constructor);
      }

      Wrapper.prototype = Object.create(Class.prototype, {
        constructor: {
          value: Wrapper,
          enumerable: false,
          writable: true,
          configurable: true
        }
      });
      return _setPrototypeOf(Wrapper, Class);
    };

    return _wrapNativeSuper(Class);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return self;
  }

  function noop() {}

  function run(fn) {
    return fn();
  }

  function blank_object() {
    return Object.create(null);
  }

  function run_all(fns) {
    fns.forEach(run);
  }

  function is_function(thing) {
    return typeof thing === 'function';
  }

  function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || a && typeof a === 'object' || typeof a === 'function';
  }

  function append(target, node) {
    target.appendChild(node);
  }

  function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
  }

  function detach(node) {
    node.parentNode.removeChild(node);
  }

  function svg_element(name) {
    return document.createElementNS('http://www.w3.org/2000/svg', name);
  }

  function text(data) {
    return document.createTextNode(data);
  }

  function empty() {
    return text('');
  }

  function attr(node, attribute, value) {
    if (value == null) node.removeAttribute(attribute);else node.setAttribute(attribute, value);
  }

  function children(element) {
    return Array.from(element.childNodes);
  }

  var current_component;

  function set_current_component(component) {
    current_component = component;
  }

  var dirty_components = [];
  var resolved_promise = Promise.resolve();
  var update_scheduled = false;
  var binding_callbacks = [];
  var render_callbacks = [];
  var flush_callbacks = [];

  function schedule_update() {
    if (!update_scheduled) {
      update_scheduled = true;
      resolved_promise.then(flush);
    }
  }

  function add_render_callback(fn) {
    render_callbacks.push(fn);
  }

  function flush() {
    var seen_callbacks = new Set();

    do {
      // first, call beforeUpdate functions
      // and update components
      while (dirty_components.length) {
        var component = dirty_components.shift();
        set_current_component(component);
        update(component.$$);
      }

      while (binding_callbacks.length) {
        binding_callbacks.shift()();
      } // then, once components are updated, call
      // afterUpdate functions. This may cause
      // subsequent updates...


      while (render_callbacks.length) {
        var callback = render_callbacks.pop();

        if (!seen_callbacks.has(callback)) {
          callback(); // ...so guard against infinite loops

          seen_callbacks.add(callback);
        }
      }
    } while (dirty_components.length);

    while (flush_callbacks.length) {
      flush_callbacks.pop()();
    }

    update_scheduled = false;
  }

  function update($$) {
    if ($$.fragment) {
      $$.update($$.dirty);
      run_all($$.before_render);
      $$.fragment.p($$.dirty, $$.ctx);
      $$.dirty = null;
      $$.after_render.forEach(add_render_callback);
    }
  }

  function mount_component(component, target, anchor) {
    var _component$$$ = component.$$,
        fragment = _component$$$.fragment,
        on_mount = _component$$$.on_mount,
        on_destroy = _component$$$.on_destroy,
        after_render = _component$$$.after_render;
    fragment.m(target, anchor); // onMount happens after the initial afterUpdate. Because
    // afterUpdate callbacks happen in reverse order (inner first)
    // we schedule onMount callbacks before afterUpdate callbacks

    add_render_callback(function () {
      var new_on_destroy = on_mount.map(run).filter(is_function);

      if (on_destroy) {
        on_destroy.push.apply(on_destroy, new_on_destroy);
      } else {
        // Edge case - component was destroyed immediately,
        // most likely as a result of a binding initialising
        run_all(new_on_destroy);
      }

      component.$$.on_mount = [];
    });
    after_render.forEach(add_render_callback);
  }

  function destroy(component, detaching) {
    if (component.$$) {
      run_all(component.$$.on_destroy);
      component.$$.fragment.d(detaching); // TODO null out other refs, including component.$$ (but need to
      // preserve final state?)

      component.$$.on_destroy = component.$$.fragment = null;
      component.$$.ctx = {};
    }
  }

  function make_dirty(component, key) {
    if (!component.$$.dirty) {
      dirty_components.push(component);
      schedule_update();
      component.$$.dirty = blank_object();
    }

    component.$$.dirty[key] = true;
  }

  function init(component, options, instance, create_fragment, not_equal$$1, prop_names) {
    var parent_component = current_component;
    set_current_component(component);
    var props = options.props || {};
    var $$ = component.$$ = {
      fragment: null,
      ctx: null,
      // state
      props: prop_names,
      update: noop,
      not_equal: not_equal$$1,
      bound: blank_object(),
      // lifecycle
      on_mount: [],
      on_destroy: [],
      before_render: [],
      after_render: [],
      context: new Map(parent_component ? parent_component.$$.context : []),
      // everything else
      callbacks: blank_object(),
      dirty: null
    };
    var ready = false;
    $$.ctx = instance ? instance(component, props, function (key, value) {
      if ($$.ctx && not_equal$$1($$.ctx[key], $$.ctx[key] = value)) {
        if ($$.bound[key]) $$.bound[key](value);
        if (ready) make_dirty(component, key);
      }
    }) : props;
    $$.update();
    ready = true;
    run_all($$.before_render);
    $$.fragment = create_fragment($$.ctx);

    if (options.target) {
      if (options.hydrate) {
        $$.fragment.l(children(options.target));
      } else {
        $$.fragment.c();
      }

      if (options.intro && component.$$.fragment.i) component.$$.fragment.i();
      mount_component(component, options.target, options.anchor);
      flush();
    }

    set_current_component(parent_component);
  }

  var SvelteElement;

  if (typeof HTMLElement !== 'undefined') {
    SvelteElement =
    /*#__PURE__*/
    function (_HTMLElement) {
      _inheritsLoose(SvelteElement, _HTMLElement);

      function SvelteElement() {
        var _this;

        _this = _HTMLElement.call(this) || this;

        _this.attachShadow({
          mode: 'open'
        });

        return _this;
      }

      var _proto = SvelteElement.prototype;

      _proto.connectedCallback = function connectedCallback() {
        // @ts-ignore todo: improve typings
        for (var key in this.$$.slotted) {
          // @ts-ignore todo: improve typings
          this.appendChild(this.$$.slotted[key]);
        }
      };

      _proto.attributeChangedCallback = function attributeChangedCallback(attr$$1, oldValue, newValue) {
        this[attr$$1] = newValue;
      };

      _proto.$destroy = function $destroy() {
        destroy(this, true);
        this.$destroy = noop;
      };

      _proto.$on = function $on(type, callback) {
        // TODO should this delegate to addEventListener?
        var callbacks = this.$$.callbacks[type] || (this.$$.callbacks[type] = []);
        callbacks.push(callback);
        return function () {
          var index = callbacks.indexOf(callback);
          if (index !== -1) callbacks.splice(index, 1);
        };
      };

      _proto.$set = function $set() {// overridden by instance, if it has props
      };

      return SvelteElement;
    }(_wrapNativeSuper(HTMLElement));
  }

  var SvelteComponent =
  /*#__PURE__*/
  function () {
    function SvelteComponent() {}

    var _proto2 = SvelteComponent.prototype;

    _proto2.$destroy = function $destroy() {
      destroy(this, true);
      this.$destroy = noop;
    };

    _proto2.$on = function $on(type, callback) {
      var callbacks = this.$$.callbacks[type] || (this.$$.callbacks[type] = []);
      callbacks.push(callback);
      return function () {
        var index = callbacks.indexOf(callback);
        if (index !== -1) callbacks.splice(index, 1);
      };
    };

    _proto2.$set = function $set() {// overridden by instance, if it has props
    };

    return SvelteComponent;
  }();

  function create_if_block(ctx) {
    var svg, g1, g0, path, path_d_value, svg_viewBox_value;
    return {
      c: function c() {
        svg = svg_element("svg");
        g1 = svg_element("g");
        g0 = svg_element("g");
        path = svg_element("path");
        attr(path, "d", path_d_value = ctx.i[4]);
        attr(path, "fill", "currentColor");
        attr(path, "transform", "translate(-256 -256)");
        attr(g0, "transform", ctx.transform);
        attr(g1, "transform", "translate(256 256)");
        attr(svg, "id", ctx.id);
        attr(svg, "class", ctx.clazz);
        attr(svg, "style", ctx.s);
        attr(svg, "viewBox", svg_viewBox_value = "0 0 " + ctx.i[0] + " " + ctx.i[1]);
        attr(svg, "aria-hidden", "true");
        attr(svg, "role", "img");
        attr(svg, "xmlns", "http://www.w3.org/2000/svg");
      },
      m: function m(target, anchor) {
        insert(target, svg, anchor);
        append(svg, g1);
        append(g1, g0);
        append(g0, path);
      },
      p: function p(changed, ctx) {
        if (changed.i && path_d_value !== (path_d_value = ctx.i[4])) {
          attr(path, "d", path_d_value);
        }

        if (changed.transform) {
          attr(g0, "transform", ctx.transform);
        }

        if (changed.id) {
          attr(svg, "id", ctx.id);
        }

        if (changed.clazz) {
          attr(svg, "class", ctx.clazz);
        }

        if (changed.s) {
          attr(svg, "style", ctx.s);
        }

        if (changed.i && svg_viewBox_value !== (svg_viewBox_value = "0 0 " + ctx.i[0] + " " + ctx.i[1])) {
          attr(svg, "viewBox", svg_viewBox_value);
        }
      },
      d: function d(detaching) {
        if (detaching) {
          detach(svg);
        }
      }
    };
  }

  function create_fragment(ctx) {
    var if_block_anchor;
    var if_block = ctx.i[4] && create_if_block(ctx);
    return {
      c: function c() {
        if (if_block) if_block.c();
        if_block_anchor = empty();
      },
      m: function m(target, anchor) {
        if (if_block) if_block.m(target, anchor);
        insert(target, if_block_anchor, anchor);
      },
      p: function p(changed, ctx) {
        if (ctx.i[4]) {
          if (if_block) {
            if_block.p(changed, ctx);
          } else {
            if_block = create_if_block(ctx);
            if_block.c();
            if_block.m(if_block_anchor.parentNode, if_block_anchor);
          }
        } else if (if_block) {
          if_block.d(1);
          if_block = null;
        }
      },
      i: noop,
      o: noop,
      d: function d(detaching) {
        if (if_block) if_block.d(detaching);

        if (detaching) {
          detach(if_block_anchor);
        }
      }
    };
  }

  function instance($$self, $$props, $$invalidate) {
    var clazz = $$props.class,
        id = $$props.id,
        _$$props$style = $$props.style,
        style = _$$props$style === void 0 ? '' : _$$props$style,
        icon = $$props.icon,
        fw = $$props.fw,
        flip = $$props.flip,
        pull = $$props.pull,
        rotate = $$props.rotate,
        size = $$props.size;
    var i;
    var s;
    var transform;

    $$self.$set = function ($$props) {
      if ('class' in $$props) $$invalidate('clazz', clazz = $$props.class);
      if ('id' in $$props) $$invalidate('id', id = $$props.id);
      if ('style' in $$props) $$invalidate('style', style = $$props.style);
      if ('icon' in $$props) $$invalidate('icon', icon = $$props.icon);
      if ('fw' in $$props) $$invalidate('fw', fw = $$props.fw);
      if ('flip' in $$props) $$invalidate('flip', flip = $$props.flip);
      if ('pull' in $$props) $$invalidate('pull', pull = $$props.pull);
      if ('rotate' in $$props) $$invalidate('rotate', rotate = $$props.rotate);
      if ('size' in $$props) $$invalidate('size', size = $$props.size);
    };

    $$self.$$.update = function ($$dirty) {
      if ($$dirty === void 0) {
        $$dirty = {
          icon: 1,
          fw: 1,
          pull: 1,
          size: 1,
          style: 1,
          flip: 1,
          rotate: 1
        };
      }

      if ($$dirty.icon) {
        $$invalidate('i', i = icon && icon.icon || [0, 0, '', [], '']);
      }

      if ($$dirty.fw || $$dirty.pull || $$dirty.size || $$dirty.style) {
        {
          var _float;

          var width;
          var height = '1em';
          var lineHeight;
          var fontSize;
          var textAlign;
          var verticalAlign = '-.125em';
          var overflow = 'visible';

          if (fw) {
            textAlign = 'center';
            width = '1.25em';
          }

          if (pull) {
            _float = pull;
          }

          if (size) {
            if (size == 'lg') {
              fontSize = '1.33333em';
              lineHeight = '.75em';
              verticalAlign = '-.225em';
            } else if (size == 'xs') {
              fontSize = '.75em';
            } else if (size == 'sm') {
              fontSize = '.875em';
            } else {
              fontSize = size.replace('x', 'em');
            }
          }

          var styleObj = {
            float: _float,
            width: width,
            height: height,
            'line-height': lineHeight,
            'font-size': fontSize,
            'text-align': textAlign,
            'vertical-align': verticalAlign,
            overflow: overflow
          };
          var styleStr = '';

          for (var prop in styleObj) {
            if (styleObj[prop]) {
              styleStr += prop + ":" + styleObj[prop] + ";";
            }
          }

          $$invalidate('s', s = styleStr + ";" + style);
        }
      }

      if ($$dirty.flip || $$dirty.rotate) {
        {
          var t = '';

          if (flip) {
            var flipX = 1;
            var flipY = 1;

            if (flip == 'horizontal') {
              flipX = -1;
            } else if (flip == 'vertical') {
              flipY = -1;
            } else {
              flipX = flipY = -1;
            }

            t += " scale(" + flipX + " " + flipY + ")";
          }

          if (rotate) {
            t += " rotate(" + rotate + " 0 0)";
          }

          $$invalidate('transform', transform = t);
        }
      }
    };

    return {
      clazz: clazz,
      id: id,
      style: style,
      icon: icon,
      fw: fw,
      flip: flip,
      pull: pull,
      rotate: rotate,
      size: size,
      i: i,
      s: s,
      transform: transform
    };
  }

  var Fa =
  /*#__PURE__*/
  function (_SvelteComponent) {
    _inheritsLoose(Fa, _SvelteComponent);

    function Fa(options) {
      var _this;

      _this = _SvelteComponent.call(this) || this;
      init(_assertThisInitialized(_this), options, instance, create_fragment, safe_not_equal, ["class", "id", "style", "icon", "fw", "flip", "pull", "rotate", "size"]);
      return _this;
    }

    return Fa;
  }(SvelteComponent);

  return Fa;

}());
